@@ -1433,7 +1433,7 @@ gdm_daemon_config_load_displays (GdmConfig *config)
 		g_strfreev (value_list);
 	}
 
-	g_ptr_array_free ((GPtrArray*) keys, TRUE);
+	g_free (keys);
 }
 
 static gboolean
@@ -1615,6 +1615,9 @@ validate_session_desktop_dir (GdmConfig          *config,
 			      GdmConfigValue     *value)
 {
 	const char *str;
+#ifdef HAVE_TSOL
+	char *new;
+#endif
 
 	str = gdm_config_value_get_string (value);
 
@@ -1622,6 +1625,12 @@ validate_session_desktop_dir (GdmConfig          *config,
 		gdm_error (_("%s: No sessions directory specified."), "gdm_config_parse");
 	}
 
+#ifdef HAVE_TSOL
+	new = g_strconcat (str, ":" DATADIR "/xsessions/multilabel/", NULL);
+	gdm_config_value_set_string (value, new);
+	g_free (new);
+#endif
+
 	return TRUE;
 }
 
